from a10sdk.common.A10BaseClass import A10BaseClass


class DnsARecord(A10BaseClass):
    
    """Class Description::
    Specify DNS Address Record.

    Class dns-a-record supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param dns_a_record_ipv6_list: {"minItems": 1, "items": {"type": "dns-a-record-ipv6"}, "uniqueItems": true, "array": [{"required": ["dns-a-record-ipv6"], "properties": {"as-replace": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP when enable ip-replace", "format": "flag"}, "dns-a-record-ipv6": {"optional": false, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}, "as-backup": {"default": 0, "optional": true, "type": "number", "description": "As backup when fail", "format": "flag"}, "weight": {"description": "Specify weight for Service-IP (Weight value)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable this Service-IP", "format": "flag"}, "static": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP in DNS server mode", "format": "flag"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL for Service-IP", "format": "number"}, "admin-ip": {"description": "Specify admin priority of Service-IP (Specify the priority)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "no-resp": {"default": 0, "optional": true, "type": "number", "description": "Don't use this Service-IP as DNS response", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-a-record-ipv6/{dns-a-record-ipv6}"}
    :param dns_a_record_ipv4_list: {"minItems": 1, "items": {"type": "dns-a-record-ipv4"}, "uniqueItems": true, "array": [{"required": ["dns-a-record-ip"], "properties": {"as-replace": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP when enable ip-replace", "format": "flag"}, "dns-a-record-ip": {"optional": false, "type": "string", "description": "Specify IP address", "format": "ipv4-address"}, "as-backup": {"default": 0, "optional": true, "type": "number", "description": "As backup when fail", "format": "flag"}, "weight": {"description": "Specify weight for Service-IP (Weight value)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable this Service-IP", "format": "flag"}, "static": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP in DNS server mode", "format": "flag"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL for Service-IP", "format": "number"}, "admin-ip": {"description": "Specify admin priority of Service-IP (Specify the priority)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "no-resp": {"default": 0, "optional": true, "type": "number", "description": "Don't use this Service-IP as DNS response", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-a-record-ipv4/{dns-a-record-ip}"}
    :param dns_a_record_srv_list: {"minItems": 1, "items": {"type": "dns-a-record-srv"}, "uniqueItems": true, "array": [{"required": ["svrname"], "properties": {"as-replace": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP when enable ip-replace", "format": "flag"}, "as-backup": {"default": 0, "optional": true, "type": "number", "description": "As backup when fail", "format": "flag"}, "weight": {"description": "Specify weight for Service-IP (Weight value)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "svrname": {"description": "Specify name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/gslb/service-ip"}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable this Service-IP", "format": "flag"}, "static": {"default": 0, "optional": true, "type": "number", "description": "Return this Service-IP in DNS server mode", "format": "flag"}, "ttl": {"optional": true, "type": "number", "description": "Specify TTL for Service-IP", "format": "number"}, "admin-ip": {"description": "Specify admin priority of Service-IP (Specify the priority)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "no-resp": {"default": 0, "optional": true, "type": "number", "description": "Don't use this Service-IP as DNS response", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/gslb/zone/{name}/service/{service-port}+{service-name}/dns-a-record/dns-a-record-srv/{svrname}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/dns-a-record`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "dns-a-record"
        self.a10_url="/axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/dns-a-record"
        self.DeviceProxy = ""
        self.dns_a_record_ipv6_list = []
        self.dns_a_record_ipv4_list = []
        self.dns_a_record_srv_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ActiveRdt(A10BaseClass):
    
    """Class Description::
    Select SLB device with the shortest round delay time to local DNS.

    Class active-rdt supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ignore_id: {"description": "Ignore IP Address specified in IP List by ID", "format": "number", "type": "number", "maximum": 31, "minimum": 0, "optional": true}
    :param keep_tracking: {"default": 0, "optional": true, "type": "number", "description": "Keep tracking client even round-delay-time samples are ready", "format": "flag"}
    :param enable: {"default": 0, "optional": true, "type": "number", "description": "Enable the active rdt", "format": "flag"}
    :param samples: {"description": "Specify samples number for round-delay-time (Number of samples,default is 5)", "format": "number", "default": 5, "optional": true, "maximum": 8, "minimum": 1, "type": "number"}
    :param skip: {"description": "Skip query if round-delay-time samples are not ready (Specify maximum skip count,default is 3)", "format": "number", "default": 3, "optional": true, "maximum": 31, "minimum": 1, "type": "number"}
    :param fail_break: {"default": 0, "optional": true, "type": "number", "description": "Break when no valid RDT", "format": "flag"}
    :param limit: {"description": "Limit of allowed RDT, default is 16383 (Limit, unit: millisecond)", "format": "number", "default": 16383, "optional": true, "maximum": 16383, "minimum": 1, "type": "number"}
    :param timeout: {"description": "Specify timeout if round-delay-time samples are not ready (Specify timeout, unit:sec,default is 3)", "format": "number", "default": 3, "optional": true, "maximum": 255, "minimum": 1, "type": "number"}
    :param single_shot: {"default": 0, "optional": true, "type": "number", "description": "Single Shot RDT", "format": "flag"}
    :param difference: {"description": "The difference between the round-delay-time, default is 0", "format": "number", "default": 0, "optional": true, "maximum": 16383, "minimum": 0, "type": "number"}
    :param tolerance: {"description": "The difference percentage between the round-delay-time, default is 10 (Tolerance)", "format": "number", "default": 10, "optional": true, "maximum": 100, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/policy/{name}/active-rdt`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "active-rdt"
        self.a10_url="/axapi/v3/gslb/policy/{name}/active-rdt"
        self.DeviceProxy = ""
        self.ignore_id = ""
        self.keep_tracking = ""
        self.enable = ""
        self.samples = ""
        self.skip = ""
        self.fail_break = ""
        self.limit = ""
        self.timeout = ""
        self.single_shot = ""
        self.difference = ""
        self.tolerance = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ipv6Network(A10BaseClass):
    
    """Class Description::
    Specify a ip address mask network to announce via BGP.

    Class ipv6-network supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param network_ipv6: {"optional": false, "type": "string", "description": "Specify a network to announce via BGP", "format": "ipv6-address-plen"}
    :param backdoor: {"default": 0, "optional": true, "type": "number", "description": "Specify a BGP backdoor route", "format": "flag"}
    :param route_map: {"description": "Route-map to modify the attributes (Name of the route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param description: {"optional": true, "type": "string", "description": "Network specific description (Up to 80 characters describing this network)", "format": "string-rlx"}
    :param comm_value: {"optional": true, "type": "string", "description": "community value in the format 1-4294967295|AA:NN|internet|local-AS|no-advertise|no-export", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/bgp/{as_number}/address-family/ipv6/network/ipv6-network/{network_ipv6}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "network_ipv6"]

        self.b_key = "ipv6-network"
        self.a10_url="/axapi/v3/router/bgp/{as_number}/address-family/ipv6/network/ipv6-network/{network_ipv6}"
        self.DeviceProxy = ""
        self.network_ipv6 = ""
        self.backdoor = ""
        self.route_map = ""
        self.description = ""
        self.comm_value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Test(A10BaseClass):
    
    """    :param locale: {"optional": true, "enum": ["zh_CN", "zh_TW", "ja_JP"], "type": "string", "description": "'zh_CN': Chinese locale for PRC; 'zh_TW': Chinese locale for Taiwan; 'ja_JP': Japanese locale for Japan; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    To test current terminal encodings for specific locale.

    Class test supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/locale/test`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "test"
        self.a10_url="/axapi/v3/locale/test"
        self.DeviceProxy = ""
        self.locale = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class WebService(A10BaseClass):
    
    """Class Description::
    Configure Web Services.

    Class web-service supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param axapi_session_limit: {"description": "Set Web service axapi Session Limit (Session limit (default 30))", "format": "number", "default": 30, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}
    :param axapi_idle: {"description": "Idle timeout of a xml service connection in minutes (Connection idle timeout value in minutes)", "partition-visibility": "shared", "default": 10, "optional": true, "format": "number", "maximum": 60, "minimum": 0, "type": "number"}
    :param server_disable: {"description": "Disable", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param secure_port: {"description": "Set web secure server port number for listening (Secure Port Number(default 443))", "partition-visibility": "shared", "default": 443, "optional": true, "format": "number", "maximum": 65535, "minimum": 1, "type": "number"}
    :param auto_redirt_disable: {"description": "Diable", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param port: {"description": "Set Web Server Port (Port number(default 80))", "partition-visibility": "shared", "default": 80, "optional": true, "format": "number", "maximum": 65535, "minimum": 1, "type": "number"}
    :param secure_server_disable: {"description": "Disable", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/web-service`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "web-service"
        self.a10_url="/axapi/v3/web-service"
        self.DeviceProxy = ""
        self.axapi_session_limit = ""
        self.axapi_idle = ""
        self.server_disable = ""
        self.secure_port = ""
        self.auto_redirt_disable = ""
        self.port = ""
        self.secure_server_disable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class TagSwitching(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param service_group: {"description": "Create a Service Group comprising Servers (Service Group Name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}
    :param equals: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Equals (Tag String)", "format": "string"}
    :param switching_type: {"enum": ["sender-comp-id", "target-comp-id"], "type": "string", "description": "'sender-comp-id': Select service group based on SenderCompID; 'target-comp-id': Select service group based on TargetCompID; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "tag-switching"
        self.DeviceProxy = ""
        self.service_group = ""
        self.equals = ""
        self.switching_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Fix(A10BaseClass):
    
    """Class Description::
    FIX template.

    Class fix supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "FIX Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param tag_switching: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"service-group": {"description": "Create a Service Group comprising Servers (Service Group Name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "optional": true, "equals": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Equals (Tag String)", "format": "string"}, "switching-type": {"enum": ["sender-comp-id", "target-comp-id"], "type": "string", "description": "'sender-comp-id': Select service group based on SenderCompID; 'target-comp-id': Select service group based on TargetCompID; ", "format": "enum"}}}]}
    :param insert_client_ip: {"default": 0, "optional": true, "type": "number", "description": "Insert client ip to tag 11447", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/fix/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "fix"
        self.a10_url="/axapi/v3/slb/template/fix/{name}"
        self.DeviceProxy = ""
        self.name = ""
        self.tag_switching = []
        self.insert_client_ip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class MultiTopologyCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param multi_topology: {"default": 0, "type": "number", "description": "Enable multi-topology mode", "format": "flag"}
    :param level_transition: {"default": 0, "type": "number", "description": "Accept and generate both IS-IS IPv6 and Multi-topology IPV6 TLVs", "format": "flag"}
    :param transition: {"default": 0, "not": "level", "type": "number", "description": "Accept and generate both IS-IS IPv6 and Multi-topology IPV6 TLVs", "format": "flag"}
    :param level: {"not": "transition", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': Level-1 only; 'level-1-2': Level-1-2; 'level-2': Level-2 only; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "multi-topology-cfg"
        self.DeviceProxy = ""
        self.multi_topology = ""
        self.level_transition = ""
        self.transition = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SummaryPrefixList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param prefix: {"type": "string", "description": "IPv6 prefix", "format": "ipv6-address-plen"}
    :param level: {"default": "level-2", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': Summarize into level-1 area; 'level-1-2': Summarize into both area and sub-domain; 'level-2': Summarize into level-2 sub-domain; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "summary-prefix-list"
        self.DeviceProxy = ""
        self.prefix = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6(A10BaseClass):
    
    """Class Description::
    Address family.

    Class ipv6 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param distance: {"description": "ISIS Administrative Distance (Distance value)", "format": "number", "default": 115, "optional": true, "maximum": 255, "minimum": 1, "type": "number"}
    :param adjacency_check: {"default": 1, "optional": true, "type": "number", "description": "Check ISIS neighbor protocol support", "format": "flag"}
    :param summary_prefix_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"prefix": {"type": "string", "description": "IPv6 prefix", "format": "ipv6-address-plen"}, "optional": true, "level": {"default": "level-2", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': Summarize into level-1 area; 'level-1-2': Summarize into both area and sub-domain; 'level-2': Summarize into level-2 sub-domain; ", "format": "enum"}}}]}
    :param default_information: {"optional": true, "enum": ["originate"], "type": "string", "description": "'originate': Distribute a default route; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/isis/{tag}/address-family/ipv6`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ipv6"
        self.a10_url="/axapi/v3/router/isis/{tag}/address-family/ipv6"
        self.DeviceProxy = ""
        self.distance = ""
        self.redistribute = {}
        self.multi_topology_cfg = {}
        self.adjacency_check = ""
        self.summary_prefix_list = []
        self.default_information = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Windows(A10BaseClass):
    
    """Class Description::
    "Windows Server, using Kerberos or NTLM for authentication".

    Class windows supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param instance_list: {"minItems": 1, "items": {"type": "instance"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"health-check-string": {"description": "Health monitor name", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/health/monitor"}, "realm": {"description": "Specify realm of Windows server", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "name": {"description": "Specify Windows authentication server name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "health-check-disable": {"description": "Disable configured health check configuration", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}, "host": {"type": "object", "properties": {"hostipv6": {"not": "hostip", "type": "string", "description": "Specify the Windows server's IPV6 address", "format": "ipv6-address"}, "hostip": {"description": "Specify the Windows server's hostname(Length 1-31) or IP address", "format": "host", "minLength": 1, "maxLength": 31, "not": "hostipv6", "type": "string"}}}, "auth-protocol": {"type": "object", "properties": {"ntlm-health-check": {"description": "Check NTLM port's health status", "format": "string", "minLength": 1, "maxLength": 31, "not": "ntlm-health-check-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}, "kport-hm-disable": {"default": 0, "not": "kport-hm", "type": "number", "description": "Disable configured Kerberos port health check configuration", "format": "flag"}, "kerberos-disable": {"default": 0, "type": "number", "description": "Disable Kerberos authentication protocol", "format": "flag"}, "ntlm-health-check-disable": {"default": 0, "not": "ntlm-health-check", "type": "number", "description": "Disable configured NTLM port health check configuration", "format": "flag"}, "kerberos-port": {"description": "Specify the Kerbros port, default is 88", "format": "number", "default": 88, "maximum": 65535, "minimum": 1, "type": "number"}, "ntlm-version": {"description": "Specify NTLM version, default is 2", "format": "number", "default": 2, "maximum": 2, "minimum": 1, "type": "number"}, "ntlm-disable": {"default": 0, "type": "number", "description": "Disable NTLM authentication protocol", "format": "flag"}, "kport-hm": {"description": "Check Kerberos port's health status", "format": "string", "minLength": 1, "maxLength": 31, "not": "kport-hm-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}}}, "timeout": {"description": "Specify connection timeout to server, default is 10 seconds", "format": "number", "default": 10, "optional": true, "maximum": 255, "minimum": 1, "type": "number"}, "health-check": {"description": "Check server's health status", "format": "flag", "default": 0, "optional": true, "not": "health-check-disable", "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/server/windows/instance/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/server/windows`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "windows"
        self.a10_url="/axapi/v3/aam/authentication/server/windows"
        self.DeviceProxy = ""
        self.instance_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Sixrd(A10BaseClass):
    
    """Class Description::
    Configure IPv6 Rapid Deployment (sixrd).

    Class sixrd supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param domain_list: {"minItems": 1, "items": {"type": "domain"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"ipv6-prefix": {"optional": true, "type": "string", "description": "IPv6 prefix", "format": "ipv6-address-plen"}, "name": {"description": "6rd Domain name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "mtu": {"description": "Tunnel MTU", "format": "number", "type": "number", "maximum": 1480, "minimum": 1280, "optional": true}, "ce-ipv4-netmask": {"optional": true, "type": "string", "description": "Mask length", "format": "ipv4-netmask-brief"}, "ce-ipv4-network": {"optional": true, "type": "string", "description": "Customer Edge IPv4 network", "format": "ipv4-address"}, "br-ipv4-address": {"optional": true, "type": "string", "description": "6rd BR IPv4 address", "format": "ipv4-address"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/sixrd/domain/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/sixrd`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "sixrd"
        self.a10_url="/axapi/v3/cgnv6/sixrd"
        self.DeviceProxy = ""
        self.domain_list = []
        self.fragmentation = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param session_creation_failure: {"description": "Session Creation Failure", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param tcp_packet_process: {"description": "TCP Packet Process", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param udp_fullcone_freed: {"description": "UDP Full-cone Freed", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param outbound_session_created: {"description": "Outbound Session Created", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param tcp_fullcone_created: {"description": "TCP Full-cone Created", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param fullcone_creation_failure: {"description": "Full-Cone Creation Failure", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param packet_inbound_deny: {"description": "Inbound Packet Denied", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param inbound_session_created: {"description": "Inbound Session Created", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param udp_fullcone_created: {"description": "UDP Full-cone Created", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param other_session_created: {"description": "Other Session Created", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param udp_session_created: {"description": "UDP Session Created", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param udp_packet_process: {"description": "UDP Packet Process", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param no_fwd_route: {"description": "No Forward Route", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param tcp_session_created: {"description": "TCP Session Created", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param other_session_freed: {"description": "Other Session Freed", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param eif_process: {"description": "Endpnt-Independent Filter Matched", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param inbound_session_freed: {"description": "Inbound Session Freed", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param udp_session_freed: {"description": "UDP Session Freed", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param no_rev_route: {"description": "No Reverse Route", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param packet_process_failure: {"description": "Packet Error Drop", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param other_packet_process: {"description": "Other Packet Process", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param tcp_fullcone_freed: {"description": "TCP Full-cone Freed", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param outbound_session_freed: {"description": "Outbound Session Freed", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param tcp_session_freed: {"description": "TCP Session Freed", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param packet_standby_drop: {"description": "Standby Drop", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.session_creation_failure = ""
        self.tcp_packet_process = ""
        self.udp_fullcone_freed = ""
        self.outbound_session_created = ""
        self.tcp_fullcone_created = ""
        self.fullcone_creation_failure = ""
        self.packet_inbound_deny = ""
        self.inbound_session_created = ""
        self.udp_fullcone_created = ""
        self.other_session_created = ""
        self.udp_session_created = ""
        self.udp_packet_process = ""
        self.no_fwd_route = ""
        self.tcp_session_created = ""
        self.other_session_freed = ""
        self.eif_process = ""
        self.inbound_session_freed = ""
        self.udp_session_freed = ""
        self.no_rev_route = ""
        self.packet_process_failure = ""
        self.other_packet_process = ""
        self.tcp_fullcone_freed = ""
        self.outbound_session_freed = ""
        self.tcp_session_freed = ""
        self.packet_standby_drop = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Global(A10BaseClass):
    
    """Class Description::
    Statistics for the object global.

    Class global supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/stateful-firewall/global/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "global"
        self.a10_url="/axapi/v3/cgnv6/stateful-firewall/global/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Dns64(A10BaseClass):
    
    """Class Description::
    Enable DNS64.

    Class dns64 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param deep_check_rr_disable: {"default": 0, "optional": true, "type": "number", "description": "Disable Check DNS Response Records", "format": "flag"}
    :param answer_only_disable: {"default": 0, "optional": true, "type": "number", "description": "Disable Only translate the Answer Section", "format": "flag"}
    :param enable: {"default": 0, "optional": true, "type": "number", "description": "Enable DNS64 (Need to config this option before config any other dns64 options)", "format": "flag"}
    :param single_response_disable: {"default": 0, "optional": true, "type": "number", "description": "Disable Single Response which is used to avoid ambiguity", "format": "flag"}
    :param max_qr_length: {"description": "Max Question Record Length, default is 128", "format": "number", "default": 128, "optional": true, "maximum": 1023, "minimum": 1, "type": "number"}
    :param ignore_rcode3_disable: {"default": 0, "optional": true, "type": "number", "description": "Disable Ignore DNS error Response with rcode 3", "format": "flag"}
    :param ttl: {"description": "Specify Max TTL in DNS Response, unit: second", "format": "number", "type": "number", "maximum": 1000000000, "minimum": 1, "optional": true}
    :param auth_data: {"default": 0, "optional": true, "type": "number", "description": "Set AA flag in DNS Response", "format": "flag"}
    :param change_query: {"default": 0, "optional": true, "type": "number", "description": "Always change incoming AAAA DNS Query to A", "format": "flag"}
    :param drop_cname_disable: {"default": 0, "optional": true, "type": "number", "description": "Disable Drop DNS CNAME Response", "format": "flag"}
    :param cache: {"default": 0, "optional": true, "type": "number", "description": "Generate Response by DNS Cache", "format": "flag"}
    :param passive_query_disable: {"default": 0, "optional": true, "type": "number", "description": "Disable Generate A query upon empty or error Response", "format": "flag"}
    :param retry: {"description": "Retry count, default is 3 (Retry Number)", "format": "number", "default": 3, "optional": true, "maximum": 15, "minimum": 0, "type": "number"}
    :param parallel_query: {"default": 0, "optional": true, "type": "number", "description": "Forward AAAA Query & generate A Query in parallel", "format": "flag"}
    :param timeout: {"description": "Timeout to send additional Queries, unit: second, default is 1", "format": "number", "default": 1, "optional": true, "maximum": 15, "minimum": 0, "type": "number"}
    :param compress_disable: {"default": 0, "optional": true, "type": "number", "description": "Disable Always try DNS Compression", "format": "flag"}
    :param trans_ptr_query: {"default": 0, "optional": true, "type": "number", "description": "Translate DNS PTR Query", "format": "flag"}
    :param trans_ptr: {"default": 0, "optional": true, "type": "number", "description": "Translate DNS PTR Records", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/dns/{name}/dns64`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "dns64"
        self.a10_url="/axapi/v3/slb/template/dns/{name}/dns64"
        self.DeviceProxy = ""
        self.deep_check_rr_disable = ""
        self.answer_only_disable = ""
        self.enable = ""
        self.single_response_disable = ""
        self.max_qr_length = ""
        self.ignore_rcode3_disable = ""
        self.ttl = ""
        self.auth_data = ""
        self.change_query = ""
        self.drop_cname_disable = ""
        self.cache = ""
        self.passive_query_disable = ""
        self.retry = ""
        self.parallel_query = ""
        self.timeout = ""
        self.compress_disable = ""
        self.trans_ptr_query = ""
        self.trans_ptr = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param tcp_frg_hdr: {"optional": true, "size": "8", "type": "number", "oid": "24", "format": "counter"}
    :param tcp_null_frg: {"optional": true, "size": "8", "type": "number", "oid": "18", "format": "counter"}
    :param over_ip_payload: {"optional": true, "size": "8", "type": "number", "oid": "10", "format": "counter"}
    :param udp_bad_csum: {"optional": true, "size": "8", "type": "number", "oid": "30", "format": "counter"}
    :param nvgre_err: {"optional": true, "size": "8", "type": "number", "oid": "37", "format": "counter"}
    :param tcp_syn_fin: {"optional": true, "size": "8", "type": "number", "oid": "20", "format": "counter"}
    :param udp_kerb_frg: {"optional": true, "size": "8", "type": "number", "oid": "28", "format": "counter"}
    :param tcp_syn_frg: {"optional": true, "size": "8", "type": "number", "oid": "23", "format": "counter"}
    :param tcp_bad_iplen: {"optional": true, "size": "8", "type": "number", "oid": "17", "format": "counter"}
    :param ipip_tnl_err: {"optional": true, "size": "8", "type": "number", "oid": "35", "format": "counter"}
    :param csum: {"optional": true, "size": "8", "type": "number", "oid": "13", "format": "counter"}
    :param tcp_xmas: {"optional": true, "size": "8", "type": "number", "oid": "21", "format": "counter"}
    :param pod: {"optional": true, "size": "8", "type": "number", "oid": "14", "format": "counter"}
    :param tcp_bad_csum: {"optional": true, "size": "8", "type": "number", "oid": "25", "format": "counter"}
    :param emp_frg: {"optional": true, "size": "8", "type": "number", "oid": "2", "format": "counter"}
    :param frg: {"optional": true, "size": "8", "type": "number", "oid": "5", "format": "counter"}
    :param bad_ip_ttl: {"optional": true, "size": "8", "type": "number", "oid": "8", "format": "counter"}
    :param bad_ip_frg_offset: {"optional": true, "size": "8", "type": "number", "oid": "12", "format": "counter"}
    :param tcp_sht_hdr: {"optional": true, "size": "8", "type": "number", "oid": "16", "format": "counter"}
    :param tcp_xmas_scan: {"optional": true, "size": "8", "type": "number", "oid": "22", "format": "counter"}
    :param no_ip_payload: {"optional": true, "size": "8", "type": "number", "oid": "9", "format": "counter"}
    :param udp_bad_len: {"optional": true, "size": "8", "type": "number", "oid": "27", "format": "counter"}
    :param opt: {"optional": true, "size": "8", "type": "number", "oid": "4", "format": "counter"}
    :param vxlan_err: {"optional": true, "size": "8", "type": "number", "oid": "36", "format": "counter"}
    :param bad_ip_payload_len: {"optional": true, "size": "8", "type": "number", "oid": "11", "format": "counter"}
    :param runt_ip_hdr: {"optional": true, "size": "8", "type": "number", "oid": "31", "format": "counter"}
    :param runt_tcp_udp_hdr: {"optional": true, "size": "8", "type": "number", "oid": "32", "format": "counter"}
    :param emp_mic_frg: {"optional": true, "size": "8", "type": "number", "oid": "3", "format": "counter"}
    :param bad_ip_hdrlen: {"optional": true, "size": "8", "type": "number", "oid": "6", "format": "counter"}
    :param tcp_null_scan: {"optional": true, "size": "8", "type": "number", "oid": "19", "format": "counter"}
    :param land: {"optional": true, "size": "8", "type": "number", "oid": "1", "format": "counter"}
    :param tcp_opt_err: {"optional": true, "size": "8", "type": "number", "oid": "34", "format": "counter"}
    :param bad_ip_flg: {"optional": true, "size": "8", "type": "number", "oid": "7", "format": "counter"}
    :param udp_srt_hdr: {"optional": true, "size": "8", "type": "number", "oid": "26", "format": "counter"}
    :param udp_port_lb: {"optional": true, "size": "8", "type": "number", "oid": "29", "format": "counter"}
    :param bad_tcp_urg_offset: {"optional": true, "size": "8", "type": "number", "oid": "15", "format": "counter"}
    :param ipip_tnl_msmtch: {"optional": true, "size": "8", "type": "number", "oid": "33", "format": "counter"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.tcp_frg_hdr = ""
        self.tcp_null_frg = ""
        self.over_ip_payload = ""
        self.udp_bad_csum = ""
        self.nvgre_err = ""
        self.tcp_syn_fin = ""
        self.udp_kerb_frg = ""
        self.tcp_syn_frg = ""
        self.tcp_bad_iplen = ""
        self.ipip_tnl_err = ""
        self.csum = ""
        self.tcp_xmas = ""
        self.pod = ""
        self.tcp_bad_csum = ""
        self.emp_frg = ""
        self.frg = ""
        self.bad_ip_ttl = ""
        self.bad_ip_frg_offset = ""
        self.tcp_sht_hdr = ""
        self.tcp_xmas_scan = ""
        self.no_ip_payload = ""
        self.udp_bad_len = ""
        self.opt = ""
        self.vxlan_err = ""
        self.bad_ip_payload_len = ""
        self.runt_ip_hdr = ""
        self.runt_tcp_udp_hdr = ""
        self.emp_mic_frg = ""
        self.bad_ip_hdrlen = ""
        self.tcp_null_scan = ""
        self.land = ""
        self.tcp_opt_err = ""
        self.bad_ip_flg = ""
        self.udp_srt_hdr = ""
        self.udp_port_lb = ""
        self.bad_tcp_urg_offset = ""
        self.ipip_tnl_msmtch = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AnomalyDrop(A10BaseClass):
    
    """Class Description::
    Statistics for the object anomaly-drop.

    Class anomaly-drop supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/anomaly-drop/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "anomaly-drop"
        self.a10_url="/axapi/v3/ip/anomaly-drop/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Priorities(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param priority: {"description": "Priority option. Define different action for each priority node. (Priority in the Group)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param priority_action: {"default": "proceed", "enum": ["drop", "drop-if-exceed-limit", "proceed", "reset", "reset-if-exceed-limit"], "type": "string", "description": "'drop': Drop request when all priority nodes fail; 'drop-if-exceed-limit': Drop request when connection over limit; 'proceed': Proceed to next priority when all priority nodes fail(default); 'reset': Send client reset when all priority nodes fail; 'reset-if-exceed-limit': Send client reset when connection over limit; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "priorities"
        self.DeviceProxy = ""
        self.priority = ""
        self.priority_action = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ServiceGroup(A10BaseClass):
    
    """Class Description::
    Service Group.

    Class service-group supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param conn_rate: {"description": "Dynamically enable stateless method by conn-rate (Rate to trigger stateless method(conn/sec))", "format": "number", "type": "number", "maximum": 1000000, "minimum": 1, "optional": true}
    :param reset_on_server_selection_fail: {"default": 0, "optional": true, "type": "number", "description": "Send reset to client if server selection fails", "format": "flag"}
    :param health_check_disable: {"description": "Disable health check", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}
    :param protocol: {"description": "'tcp': TCP LB service; 'udp': UDP LB service; ", "format": "enum", "type": "string", "enum": ["tcp", "udp"], "modify-not-allowed": 1, "optional": true}
    :param traffic_replication_mirror: {"default": 0, "optional": true, "type": "number", "description": "Mirror Bi-directional Packet", "format": "flag"}
    :param traffic_replication_mirror_ip_repl: {"default": 0, "optional": true, "type": "number", "description": "Replaces IP with server-IP", "format": "flag"}
    :param reset_priority_affinity: {"default": 0, "optional": true, "type": "number", "description": "Reset", "format": "flag"}
    :param min_active_member: {"description": "Minimum Active Member Per Priority (Minimum Active Member before Action)", "format": "number", "type": "number", "maximum": 63, "minimum": 1, "optional": true}
    :param member_list: {"minItems": 1, "items": {"type": "member"}, "uniqueItems": true, "array": [{"required": ["name", "port"], "properties": {"member-priority": {"description": "Priority of Port in the Group", "format": "number", "type": "number", "maximum": 16, "minimum": 1, "optional": true}, "name": {"description": "Member name", "format": "comp-string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/server"}, "fqdn-name": {"description": "Server hostname - Not applicable if real server is already defined", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "member-template": {"description": "Real server port template (Real server port template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/port"}, "host": {"optional": true, "type": "string", "description": "IP Address - Not applicable if real server is already defined", "format": "ipv4-address"}, "member-state": {"description": "'enable': Enable member service port; 'disable': Disable member service port; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "server-ipv6-addr": {"optional": true, "type": "string", "description": "IPV6 Address - Not applicable if real server is already defined", "format": "ipv6-address"}, "port": {"description": "Port number", "format": "number", "default": 65534, "optional": false, "maximum": 65534, "minimum": 0, "type": "number", "$ref": "/axapi/v3/slb/server/port"}, "member-stats-data-disable": {"default": 0, "optional": true, "type": "number", "description": "Disable statistical data collection", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/slb/service-group/{name}/member/{name}+{port}"}
    :param stats_data_action: {"description": "'stats-data-enable': Enable statistical data collection for service group; 'stats-data-disable': Disable statistical data collection for service group; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}
    :param traffic_replication_mirror_da_repl: {"default": 0, "optional": true, "type": "number", "description": "Replace Destination MAC", "format": "flag"}
    :param rpt_ext_server: {"default": 0, "optional": true, "type": "number", "description": "Report top 10 fastest/slowest servers", "format": "flag"}
    :param template_port: {"description": "Port template (Port template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/port"}
    :param conn_rate_grace_period: {"description": "Define the grace period during transition (Define the grace period during transition(seconds))", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}
    :param l4_session_usage_duration: {"description": "Period that trigger condition consistently happens(seconds)", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}
    :param backup_server_event_log: {"default": 0, "optional": true, "type": "number", "description": "Send log info on back up server events", "format": "flag"}
    :param lc_method: {"description": "'least-connection': Least connection on server level; 'service-least-connection': Least connection on service port level; 'weighted-least-connection': Weighted least connection on server level; 'service-weighted-least-connection': Weighted least connection on service port level; ", "format": "enum", "optional": true, "enum": ["least-connection", "service-least-connection", "weighted-least-connection", "service-weighted-least-connection"], "not-list": ["lb-method", "stateless-lb-method"], "type": "string"}
    :param pseudo_round_robin: {"default": 0, "optional": true, "type": "number", "description": "PRR, select the oldest node for sub-select", "format": "flag"}
    :param l4_session_usage_revert_rate: {"description": "Usage to revert to statelful method", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}
    :param template_server: {"description": "Server template (Server template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/server"}
    :param stateless_lb_method: {"description": "'stateless-dst-ip-hash': Stateless load-balancing based on Dst IP and Dst port hash; 'stateless-per-pkt-round-robin': Stateless load-balancing using per-packet round-robin; 'stateless-src-dst-ip-hash': Stateless load-balancing based on IP and port hash for both Src and Dst; 'stateless-src-ip-hash': Stateless load-balancing based on Src IP and Src port hash; 'stateless-src-ip-only-hash': Stateless load-balancing based on only Src IP hash; ", "format": "enum", "optional": true, "enum": ["stateless-dst-ip-hash", "stateless-per-pkt-round-robin", "stateless-src-dst-ip-hash", "stateless-src-ip-hash", "stateless-src-ip-only-hash"], "not-list": ["lb-method", "lc-method"], "type": "string"}
    :param l4_session_revert_duration: {"description": "Period that revert condition consistently happens(seconds)", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}
    :param traffic_replication_mirror_sa_da_repl: {"default": 0, "optional": true, "type": "number", "description": "Replace Source MAC and Destination MAC", "format": "flag"}
    :param lb_method: {"description": "'dst-ip-hash': Load-balancing based on only Dst IP and Port hash; 'dst-ip-only-hash': Load-balancing based on only Dst IP hash; 'fastest-response': Fastest response time on service port level; 'least-request': Least request on service port level; 'src-ip-hash': Load-balancing based on only Src IP and Port hash; 'src-ip-only-hash': Load-balancing based on only Src IP hash; 'weighted-rr': Weighted round robin on server level; 'round-robin': Round robin on server level; 'round-robin-strict': Strict mode round robin on server level; ", "format": "enum", "default": "round-robin", "optional": true, "enum": ["dst-ip-hash", "dst-ip-only-hash", "fastest-response", "least-request", "src-ip-hash", "src-ip-only-hash", "weighted-rr", "round-robin", "round-robin-strict"], "not-list": ["lc-method", "stateless-lb-method"], "type": "string"}
    :param stateless_auto_switch: {"default": 0, "optional": true, "type": "number", "description": "Enable auto stateless method", "format": "flag"}
    :param min_active_member_action: {"optional": true, "enum": ["dynamic-priority", "skip-pri-set"], "type": "string", "description": "'dynamic-priority': dynamic change member priority to met the min-active-member requirement; 'skip-pri-set': Skip Current Priority Set If Min not met; ", "format": "enum"}
    :param l4_session_usage: {"description": "Dynamically enable stateless method by session usage (Usage to trigger stateless method)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}
    :param extended_stats: {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on service group", "format": "flag"}
    :param conn_rate_revert_duration: {"description": "Period that revert condition consistently happens(seconds)", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}
    :param conn_rate_log: {"default": 0, "optional": true, "type": "number", "description": "Send log if transition happens", "format": "flag"}
    :param traffic_replication_mirror_sa_repl: {"default": 0, "optional": true, "type": "number", "description": "Replace Source MAC", "format": "flag"}
    :param report_delay: {"description": "Reporting frequency (in minutes)", "format": "number", "type": "number", "maximum": 7200, "minimum": 1, "optional": true}
    :param name: {"description": "SLB Service Name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}
    :param l4_session_usage_log: {"default": 0, "optional": true, "type": "number", "description": "Send log if transition happens", "format": "flag"}
    :param conn_rate_duration: {"description": "Period that trigger condition consistently happens(seconds)", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}
    :param l4_session_usage_grace_period: {"description": "Define the grace period during transition (Define the grace period during transition(seconds))", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}
    :param template_policy: {"description": "Policy template (Policy template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/policy"}
    :param stateless_lb_method2: {"optional": true, "enum": ["stateless-dst-ip-hash", "stateless-per-pkt-round-robin", "stateless-src-dst-ip-hash", "stateless-src-ip-hash", "stateless-src-ip-only-hash"], "type": "string", "description": "'stateless-dst-ip-hash': Stateless load-balancing based on Dst IP and Dst port hash; 'stateless-per-pkt-round-robin': Stateless load-balancing using per-packet round-robin; 'stateless-src-dst-ip-hash': Stateless load-balancing based on IP and port hash for both Src and Dst; 'stateless-src-ip-hash': Stateless load-balancing based on Src IP and Src port hash; 'stateless-src-ip-only-hash': Stateless load-balancing based on only Src IP hash; ", "format": "enum"}
    :param priorities: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Priority option. Define different action for each priority node. (Priority in the Group)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "priority-action": {"default": "proceed", "enum": ["drop", "drop-if-exceed-limit", "proceed", "reset", "reset-if-exceed-limit"], "type": "string", "description": "'drop': Drop request when all priority nodes fail; 'drop-if-exceed-limit': Drop request when connection over limit; 'proceed': Proceed to next priority when all priority nodes fail(default); 'reset': Send client reset when all priority nodes fail; 'reset-if-exceed-limit': Send client reset when connection over limit; ", "format": "enum"}, "optional": true}}]}
    :param sample_rsp_time: {"default": 0, "optional": true, "type": "number", "description": "sample server response time", "format": "flag"}
    :param top_fastest: {"default": 0, "optional": true, "type": "number", "description": "Report top 10 fastest servers", "format": "flag"}
    :param conn_revert_rate: {"description": "Rate to revert to statelful method (conn/sec)", "format": "number", "type": "number", "maximum": 1000000, "minimum": 1, "optional": true}
    :param priority_affinity: {"default": 0, "optional": true, "type": "number", "description": "Priority affinity. Persist to the same priority if possible.", "format": "flag"}
    :param top_slowest: {"default": 0, "optional": true, "type": "number", "description": "Report top 10 slowest servers", "format": "flag"}
    :param health_check: {"description": "Health Check (Monitor Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "health-check-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/service-group/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "service-group"
        self.a10_url="/axapi/v3/slb/service-group/{name}"
        self.DeviceProxy = ""
        self.conn_rate = ""
        self.reset_on_server_selection_fail = ""
        self.health_check_disable = ""
        self.protocol = ""
        self.traffic_replication_mirror = ""
        self.traffic_replication_mirror_ip_repl = ""
        self.reset_priority_affinity = ""
        self.min_active_member = ""
        self.member_list = []
        self.stats_data_action = ""
        self.traffic_replication_mirror_da_repl = ""
        self.rpt_ext_server = ""
        self.template_port = ""
        self.conn_rate_grace_period = ""
        self.l4_session_usage_duration = ""
        self.backup_server_event_log = ""
        self.lc_method = ""
        self.pseudo_round_robin = ""
        self.l4_session_usage_revert_rate = ""
        self.template_server = ""
        self.stateless_lb_method = ""
        self.l4_session_revert_duration = ""
        self.traffic_replication_mirror_sa_da_repl = ""
        self.lb_method = ""
        self.stateless_auto_switch = ""
        self.min_active_member_action = ""
        self.l4_session_usage = ""
        self.extended_stats = ""
        self.conn_rate_revert_duration = ""
        self.conn_rate_log = ""
        self.reset = {}
        self.traffic_replication_mirror_sa_repl = ""
        self.report_delay = ""
        self.name = ""
        self.l4_session_usage_log = ""
        self.conn_rate_duration = ""
        self.l4_session_usage_grace_period = ""
        self.template_policy = ""
        self.stateless_lb_method2 = ""
        self.priorities = []
        self.sample_rsp_time = ""
        self.top_fastest = ""
        self.conn_revert_rate = ""
        self.priority_affinity = ""
        self.top_slowest = ""
        self.health_check = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class CookieValue(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cookie_value: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify cookie in POST packet", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "cookie-value"
        self.DeviceProxy = ""
        self.cookie_value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Cookie(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "cookie"
        self.DeviceProxy = ""
        self.cookie_value = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RequestUri(A10BaseClass):
    
    """Class Description::
    URI of authentication web page.

    Class request-uri supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param other_variables: {"description": "Specify other variables (n1=v1&n2=v2) in form relay", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param action_uri: {"description": "Specify the action-URI", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param uri: {"description": "Specify request URI", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}
    :param user_variable: {"description": "Specify username variable name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param domain_variable: {"description": "Specify domain variable name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param password_variable: {"description": "Specify password variable name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param match_type: {"optional": false, "enum": ["equals", "contains", "starts-with", "ends-with"], "type": "string", "description": "'equals': URI exactly matches the string; 'contains': URI string contains another sub string; 'starts-with': URI string starts with sub string; 'ends-with': URI string ends with sub string; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/relay/form-based/instance/{name}/request-uri/{match_type}+{uri}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "match_type","uri"]

        self.b_key = "request-uri"
        self.a10_url="/axapi/v3/aam/authentication/relay/form-based/instance/{name}/request-uri/{match_type}+{uri}"
        self.DeviceProxy = ""
        self.other_variables = ""
        self.action_uri = ""
        self.uri = ""
        self.cookie = {}
        self.user_variable = ""
        self.domain_variable = ""
        self.password_variable = ""
        self.match_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class CreateOper(A10BaseClass):
    
    """    :param csr_generate: {"default": 0, "optional": true, "type": "number", "format": "flag"}
    :param division: {"minLength": 1, "maxLength": 63, "type": "string", "optional": true, "format": "string-rlx"}
    :param locality: {"minLength": 1, "maxLength": 63, "type": "string", "optional": true, "format": "string-rlx"}
    :param bits: {"description": "'1024': 1024; '2048': 2048; '4096': 4096; ", "format": "enum", "default": "1024", "type": "string", "enum": ["1024", "2048", "4096"], "optional": true}
    :param state_province: {"minLength": 1, "maxLength": 31, "type": "string", "optional": true, "format": "string-rlx"}
    :param filename: {"minLength": 1, "maxLength": 255, "type": "string", "optional": false, "format": "string"}
    :param common_name: {"minLength": 1, "maxLength": 64, "type": "string", "optional": true, "format": "string-rlx"}
    :param country: {"minLength": 2, "maxLength": 3, "type": "string", "optional": true, "format": "string"}
    :param organization: {"minLength": 1, "maxLength": 63, "type": "string", "optional": true, "format": "string-rlx"}
    :param valid_days: {"format": "number", "default": 730, "type": "number", "maximum": 3650, "minimum": 30, "optional": true}
    :param email: {"minLength": 1, "maxLength": 64, "type": "string", "optional": true, "format": "email-addr"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    .

    Class create-oper supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/pki/create-oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "create-oper"
        self.a10_url="/axapi/v3/pki/create-oper"
        self.DeviceProxy = ""
        self.csr_generate = ""
        self.division = ""
        self.locality = ""
        self.bits = ""
        self.state_province = ""
        self.filename = ""
        self.common_name = ""
        self.country = ""
        self.organization = ""
        self.valid_days = ""
        self.email = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Udp(A10BaseClass):
    
    """Class Description::
    Set UDP STUN timeout.

    Class udp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param port_start: {"description": "Port Range (Port Range Start)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param port_end: {"description": "Port Range (Port Range End)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param timeout: {"description": "STUN timeout in minutes (default: 2 minutes)", "format": "number", "type": "number", "maximum": 60, "minimum": 0, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn/stun-timeout/udp/{port_start}+{port_end}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "port_start","port_end"]

        self.b_key = "udp"
        self.a10_url="/axapi/v3/cgnv6/lsn/stun-timeout/udp/{port_start}+{port_end}"
        self.DeviceProxy = ""
        self.port_start = ""
        self.port_end = ""
        self.timeout = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ConnectionLoad(A10BaseClass):
    
    """Class Description::
    Select Service-IP with the lowest connection-load.

    Class connection-load supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param connection_load_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable connection-load", "format": "flag"}
    :param connection_load_interval: {"description": "Interval between two samples, Unit: second (Interval value,default is 5)", "format": "number", "default": 5, "optional": true, "maximum": 60, "minimum": 1, "type": "number"}
    :param limit: {"default": 0, "optional": true, "type": "number", "description": "Limit of maxinum connection load, default is unlimited", "format": "flag"}
    :param connection_load_samples: {"description": "Specify samples for connection-load (Number of samples used to calculate the connection load, default is 5)", "format": "number", "default": 5, "optional": true, "maximum": 8, "minimum": 1, "type": "number"}
    :param connection_load_limit: {"description": "The value of the connection-load limit, default is unlimited", "format": "number", "type": "number", "maximum": 999999999, "minimum": 1, "optional": true}
    :param connection_load_fail_break: {"default": 0, "optional": true, "type": "number", "description": "Break when exceed limit", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/policy/{name}/connection-load`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "connection-load"
        self.a10_url="/axapi/v3/gslb/policy/{name}/connection-load"
        self.DeviceProxy = ""
        self.connection_load_enable = ""
        self.connection_load_interval = ""
        self.limit = ""
        self.connection_load_samples = ""
        self.connection_load_limit = ""
        self.connection_load_fail_break = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Radius(A10BaseClass):
    
    """Class Description::
    RADIUS type.

    Class radius supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param radius_username: {"description": "Specify the username", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param radius_password_string: {"description": "Configure password, '' means empty passworddd", "format": "password", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param radius_encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param radius_response_code: {"description": "Specify response code range (e.g. 2,4-7) (Format is xx,xx-xx (xx between [1, 13]))", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param radius_expect: {"default": 0, "optional": true, "type": "number", "description": "Specify what you expect from the response message", "format": "flag"}
    :param radius: {"default": 0, "optional": true, "type": "number", "description": "RADIUS type", "format": "flag"}
    :param radius_secret: {"description": "Specify the shared secret of RADIUS server (Shared Crypto Key)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param radius_password: {"default": 0, "optional": true, "type": "number", "description": "Specify the user password", "format": "flag"}
    :param radius_port: {"description": "Specify the RADIUS port, default is 1812 (Port number (default 1812))", "format": "number", "default": 1812, "optional": true, "maximum": 65534, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health/monitor/{name}/method/radius`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "radius"
        self.a10_url="/axapi/v3/health/monitor/{name}/method/radius"
        self.DeviceProxy = ""
        self.radius_username = ""
        self.radius_password_string = ""
        self.radius_encrypted = ""
        self.radius_response_code = ""
        self.radius_expect = ""
        self.radius = ""
        self.radius_secret = ""
        self.radius_password = ""
        self.radius_port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Interface(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ethernet: {"not-list": ["ve", "management"], "type": "number", "description": "configure lldp management-address interface ethernet. help-val lldp management-address interface port number", "format": "interface"}
    :param management: {"default": 0, "not-list": ["ethernet", "ve"], "type": "number", "description": "configure lldp management-address interface management", "format": "flag"}
    :param ve: {"description": "configure lldp management-address interface management. help-val lldp management-address interface port number", "format": "number", "not-list": ["ethernet", "management"], "maximum": 4094, "minimum": 2, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "interface"
        self.DeviceProxy = ""
        self.ethernet = ""
        self.management = ""
        self.ve = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Dns(A10BaseClass):
    
    """Class Description::
    Configure lldp management-address dns address.

    Class dns supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param dns: {"description": "Configure lldp management-address, subtype is dns. help-val lldp management-address dns address", "format": "string", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/lldp/management-address/dns/{dns}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "dns"]

        self.b_key = "dns"
        self.a10_url="/axapi/v3/lldp/management-address/dns/{dns}"
        self.DeviceProxy = ""
        self.interface = {}
        self.dns = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class External(A10BaseClass):
    
    """Class Description::
    EXTERNAL type.

    Class external supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ext_preference: {"default": 0, "optional": true, "type": "number", "description": "Get server's perference", "format": "flag"}
    :param ext_port: {"description": "Specify the server port (Port Number)", "format": "number", "type": "number", "maximum": 65534, "minimum": 1, "optional": true}
    :param external: {"default": 0, "optional": true, "type": "number", "description": "EXTERNAL type", "format": "flag"}
    :param ext_arguments: {"description": "Specify external application's arguments (Application arguments)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param ext_program: {"description": "Specify external application (Program name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health/monitor/{name}/method/external`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "external"
        self.a10_url="/axapi/v3/health/monitor/{name}/method/external"
        self.DeviceProxy = ""
        self.ext_preference = ""
        self.ext_port = ""
        self.external = ""
        self.ext_arguments = ""
        self.ext_program = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Inbound(A10BaseClass):
    
    """Class Description::
    Fragmentation Behavior from NAT outside to NAT inside.

    Class inbound supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param count: {"description": "Configure number of ICMP messages sent when DF set. Default is 1", "format": "number", "default": 1, "optional": true, "maximum": 5, "minimum": 1, "type": "number"}
    :param frag_action: {"description": "'drop': Drop Silently; 'ipv6': Use IPv6 fragmentation for oversize packets (default); ", "format": "enum", "default": "ipv6", "type": "string", "enum": ["drop", "ipv6"], "optional": true}
    :param df_set: {"description": "'drop': Drop Silently; 'ipv6': Use IPv6 fragmentation; 'send-icmp': Send ICMP Type 3 Code 4 (Fragmentation Needed and DF Set) (default); ", "format": "enum", "default": "send-icmp", "type": "string", "enum": ["drop", "ipv6", "send-icmp"], "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/nat64/fragmentation/inbound`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "inbound"
        self.a10_url="/axapi/v3/cgnv6/nat64/fragmentation/inbound"
        self.DeviceProxy = ""
        self.count = ""
        self.frag_action = ""
        self.df_set = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Other_error: {"description": "Total Other Error", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param Timeout_error: {"description": "Total Timeout", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param Request_send: {"description": "Total Request Send", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param Response_get: {"description": "Total Response Get", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.Other_error = ""
        self.Timeout_error = ""
        self.Request_send = ""
        self.Response_get = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Kerberos(A10BaseClass):
    
    """Class Description::
    Statistics for the object kerberos.

    Class kerberos supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param instance_list: {"minItems": 1, "items": {"type": "instance"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"stats": {"type": "object", "properties": {"Tickets": {"description": "Tickets", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}, "Response-receive": {"description": "Response Receive", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}, "Request-send": {"description": "Request Send", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}, "Current-requets-of-user": {"description": "Current Pending Requests of User", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}}}, "name": {"description": "Specify Kerberos authentication relay name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/relay/kerberos/instance/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/relay/kerberos/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "kerberos"
        self.a10_url="/axapi/v3/aam/authentication/relay/kerberos/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.instance_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ldap(A10BaseClass):
    
    """Class Description::
    LDAP type.

    Class ldap supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ldap_port: {"description": "Specify the LDAP port (Speciry port number, default is 389, or 636 if LDAP over SSL)", "format": "number", "default": 389, "optional": true, "maximum": 65534, "minimum": 1, "type": "number"}
    :param ldap_password_string: {"description": "Configure password, '' means empty passworddd", "format": "password", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param ldap_encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param BaseDN: {"description": "Specify LDAP DN distinguished name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param ldap_query: {"description": "LDAP query to be excuted", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param ldap_binddn: {"description": "Specify the distinguished name for bindRequest (LDAP DN distinguished name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param ldap_password: {"default": 0, "optional": true, "type": "number", "description": "Specify the user password", "format": "flag"}
    :param ldap_security: {"optional": true, "enum": ["overssl", "StartTLS"], "type": "string", "description": "'overssl': Set LDAP over SSL; 'StartTLS': LDAP switch to TLS; ", "format": "enum"}
    :param ldap: {"default": 0, "optional": true, "type": "number", "description": "LDAP type", "format": "flag"}
    :param AcceptNotFound: {"default": 0, "optional": true, "type": "number", "description": "Mark server up on receiving a not-found response", "format": "flag"}
    :param ldap_run_search: {"default": 0, "optional": true, "type": "number", "description": "Specify a query to be executed", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health/monitor/{name}/method/ldap`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ldap"
        self.a10_url="/axapi/v3/health/monitor/{name}/method/ldap"
        self.DeviceProxy = ""
        self.ldap_port = ""
        self.ldap_password_string = ""
        self.ldap_encrypted = ""
        self.BaseDN = ""
        self.ldap_query = ""
        self.ldap_binddn = ""
        self.ldap_password = ""
        self.ldap_security = ""
        self.ldap = ""
        self.AcceptNotFound = ""
        self.ldap_run_search = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SlbChange(A10BaseClass):
    
    """Class Description::
    Enable SLB change traps.

    Class slb-change supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param all: {"default": 0, "optional": true, "type": "number", "description": "Enable all system group traps", "format": "flag"}
    :param resource_usage_warning: {"default": 0, "optional": true, "type": "number", "description": "Enable partition resource usage warning trap", "format": "flag"}
    :param ssl_cert_change: {"default": 0, "optional": true, "type": "number", "description": "Enable SSL certificate change trap", "format": "flag"}
    :param ssl_cert_expire: {"default": 0, "optional": true, "type": "number", "description": "Enable SSL certificate expiring trap", "format": "flag"}
    :param server: {"default": 0, "optional": true, "type": "number", "description": "Enable slb server create/delete trap", "format": "flag"}
    :param vip: {"default": 0, "optional": true, "type": "number", "description": "Enable slb vip create/delete trap", "format": "flag"}
    :param connection_resource_event: {"default": 0, "optional": true, "type": "number", "description": "Enable system connection resource event trap", "format": "flag"}
    :param server_port: {"default": 0, "optional": true, "type": "number", "description": "Enable slb server port create/delete trap", "format": "flag"}
    :param vip_port: {"default": 0, "optional": true, "type": "number", "description": "Enable slb vip-port create/delete trap", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/enable/traps/slb-change`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "slb-change"
        self.a10_url="/axapi/v3/snmp-server/enable/traps/slb-change"
        self.DeviceProxy = ""
        self.A10WW_all = ""
        self.resource_usage_warning = ""
        self.ssl_cert_change = ""
        self.ssl_cert_expire = ""
        self.server = ""
        self.vip = ""
        self.connection_resource_event = ""
        self.server_port = ""
        self.vip_port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Vpn(A10BaseClass):
    
    """Class Description::
    VPN Commands.

    Class vpn supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ipsec_list: {"minItems": 1, "items": {"type": "ipsec"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"lifebytes": {"description": "IPsec SA age in megabytes", "format": "number", "default": 0, "optional": true, "maximum": 8000000, "minimum": 0, "type": "number"}, "ike-gateway": {"description": "Gateway to use for IPsec SA", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/vpn/ike-gateway"}, "name": {"description": "IPsec name", "format": "string", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}, "dh-group": {"optional": true, "enum": ["0", "1", "2", "5", "14", "15", "16", "18"], "type": "string", "description": "'0': Diffie-Hellman group 0 (Default); '1': Diffie-Hellman group 1; '2': Diffie-Hellman group 2; '5': Diffie-Hellman group 5; '14': Diffie-Hellman group 14; '15': Diffie-Hellman group 15; '16': Diffie-Hellman group 16; '18': Diffie-Hellman group 18; ", "format": "enum"}, "proto": {"description": "'esp': Encapsulating security protocol (Default); ", "format": "enum", "default": "esp", "type": "string", "enum": ["esp"], "optional": true}, "bind": {"type": "object", "properties": {"tunnel": {"description": "Tunnel interface index", "format": "number", "maximum": 128, "minimum": 1, "type": "number", "$ref": "/axapi/v3/interface/tunnel"}, "next-hop": {"type": "string", "description": "IPsec Next Hop IP Address", "format": "ipv4-address"}}}, "up": {"default": 0, "optional": true, "type": "number", "description": "Initiates SA negotiation to bring the IPsec connection up", "format": "flag"}, "anti-replay-window": {"optional": true, "enum": ["0", "16", "32", "64", "128", "256"], "type": "string", "description": "'0': Disable Anti-Replay Window Check; '16': Window Size of 16 bits; '32': Window Size of 32 bits; '64': Window Size of 64 bits; '128': Window Size of 128 bits; '256': Window Size of 256 bits; ", "format": "enum"}, "traffic-selector": {"type": "object", "properties": {"ipv4": {"type": "object", "properties": {"remote": {"type": "string", "description": "IPv4 Address", "format": "ipv4-address"}, "local_protocol": {"description": "IP Protocol Number (0-255)", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}, "local_port": {"description": "Port Number", "minimum": 0, "type": "number", "maximum": 65535, "format": "number"}, "remote_port": {"description": "Port Number", "minimum": 0, "type": "number", "maximum": 65535, "format": "number"}, "local_netmask": {"type": "string", "description": "IPv4 Address Network Mask", "format": "ipv4-netmask"}, "remote_netmask": {"type": "string", "description": "IPv4 Address Network Mask", "format": "ipv4-netmask"}, "remote_protocol": {"description": "IP Protocol Number (0-255)", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}, "local": {"type": "string", "description": "Local Traffic Selector", "format": "ipv4-address"}}}}}, "mode": {"description": "'tunnel': Encapsulating the packet in IPsec tunnel mode (Default); ", "format": "enum", "default": "tunnel", "type": "string", "enum": ["tunnel"], "optional": true}, "lifetime": {"description": "IPsec SA age in seconds", "format": "number", "default": 28800, "optional": true, "maximum": 28800, "minimum": 30, "type": "number"}, "enc-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Prioritizes (1-10) security protocol, least value has highest priority", "format": "number", "default": 5, "maximum": 10, "minimum": 1, "type": "number"}, "encryption": {"enum": ["des", "3des", "aes-128", "aes-192", "aes-256", "null"], "type": "string", "description": "'des': Data Encryption Standard algorithm; '3des': Triple Data Encryption Standard algorithm; 'aes-128': Advanced Encryption Standard algorithm (key size: 128 bits); 'aes-192': Advanced Encryption Standard algorithm (key size: 192 bits); 'aes-256': Advanced Encryption Standard algorithm (key size: 256 bits); 'null': No encryption algorithm; ", "format": "enum"}, "hash": {"enum": ["md5", "sha1", "sha256", "null"], "type": "string", "description": "'md5': MD5 Dessage-Digest Algorithm; 'sha1': Secure Hash Algorithm 1; 'sha256': Secure Hash Algorithm 256; 'null': No hash algorithm; ", "format": "enum"}, "optional": true}}]}}}], "type": "array", "$ref": "/axapi/v3/vpn/ipsec/{name}"}
    :param fragment_after_encap: {"default": 0, "optional": true, "type": "number", "description": "Fragment after adding IPsec headers", "format": "flag"}
    :param revocation_list: {"minItems": 1, "items": {"type": "revocation"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"ca": {"description": "Certificate Authority file name", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "name": {"description": "Revocation name", "format": "string", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}, "crl": {"type": "object", "properties": {"crl-sec": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Secondary CRL File Name or URL (http://www.example.com/ocsp) (only .der filetypes)", "format": "string-rlx"}, "crl-pri": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Primary CRL File Name or URL (http://www.example.com/ocsp) (only .der filetypes)", "format": "string-rlx"}}}, "ocsp": {"type": "object", "properties": {"ocsp-pri": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Primary OCSP Authentication Server", "format": "string"}, "ocsp-sec": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Secondary OCSP Authentication Server", "format": "string"}}}}}], "type": "array", "$ref": "/axapi/v3/vpn/revocation/{name}"}
    :param ike_gateway_list: {"minItems": 1, "items": {"type": "ike-gateway"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"remote-ca-cert": {"type": "object", "properties": {"remote-cert-name": {"minLength": 1, "maxLength": 127, "type": "string", "description": "CA Certificate DN", "format": "string-rlx"}}}, "local-address": {"type": "object", "properties": {"local-ip": {"type": "string", "description": "Ipv4 address", "format": "ipv4-address"}}}, "name": {"description": "IKE-gateway name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "dh-group": {"optional": true, "enum": ["1", "2", "5", "14", "15", "16", "18"], "type": "string", "description": "'1': Diffie-Hellman group 1 (Default); '2': Diffie-Hellman group 2; '5': Diffie-Hellman group 5; '14': Diffie-Hellman group 14; '15': Diffie-Hellman group 15; '16': Diffie-Hellman group 16; '18': Diffie-Hellman group 18; ", "format": "enum"}, "nat-traversal": {"default": 0, "optional": true, "type": "number", "format": "flag"}, "vrid": {"type": "object", "properties": {"default": {"default": 0, "not": "vrid-num", "type": "number", "description": "Default VRRP-A vrid", "format": "flag"}, "vrid-num": {"description": "Specify ha VRRP-A vrid", "format": "number", "maximum": 31, "minimum": 1, "not": "default", "type": "number"}}}, "ike-version": {"optional": true, "enum": ["v1", "v2"], "type": "string", "description": "'v1': IKEv1 key exchange; 'v2': IKEv2 key exchange; ", "format": "enum"}, "local-cert": {"type": "object", "properties": {"local-cert-name": {"minLength": 1, "maxLength": 64, "type": "string", "description": "Certificate File Name", "format": "string"}}}, "dpd": {"type": "object", "properties": {"interval": {"description": "Interval time in seconds", "minimum": 0, "type": "number", "maximum": 10, "format": "number"}, "retry": {"description": "Retry times", "minimum": 1, "type": "number", "maximum": 10, "format": "number"}}}, "mode": {"optional": true, "enum": ["main", "aggressive"], "type": "string", "description": "'main': Negotiate Main mode (Default); 'aggressive': Negotiate Aggressive mode; ", "format": "enum"}, "key": {"type": "object", "properties": {"key-passphrase": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Private Key Pass Phrase", "format": "string"}, "key-name": {"minLength": 1, "maxLength": 64, "type": "string", "description": "Private Key File Name", "format": "string"}}}, "lifetime": {"description": "IKE SA age in seconds", "format": "number", "default": 86400, "optional": true, "maximum": 86400, "minimum": 300, "type": "number"}, "remote-address": {"type": "object", "properties": {"remote-ip": {"not": "dns", "type": "string", "description": "Ipv4 address", "format": "ipv4-address"}, "dns": {"description": "Remote IP based on Domain name", "format": "string", "minLength": 1, "maxLength": 128, "not": "remote-ip", "type": "string"}}}, "remote-id": {"description": "Remote Gateway Identity", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "local-id": {"description": "Local Gateway Identity", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "enc-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Prioritizes (1-10) security protocol, least value has highest priority", "format": "number", "default": 5, "maximum": 10, "minimum": 1, "type": "number"}, "encryption": {"enum": ["des", "3des", "aes-128", "aes-192", "aes-256", "null"], "type": "string", "description": "'des': Data Encryption Standard algorithm; '3des': Triple Data Encryption Standard algorithm; 'aes-128': Advanced Encryption Standard algorithm (key size: 128 bits); 'aes-192': Advanced Encryption Standard algorithm (key size: 192 bits); 'aes-256': Advanced Encryption Standard algorithm (key size: 256 bits); 'null': No encryption algorithm; ", "format": "enum"}, "hash": {"enum": ["md5", "sha1", "sha256", "null"], "type": "string", "description": "'md5': MD5 Dessage-Digest Algorithm; 'sha1': Secure Hash Algorithm 1; 'sha256': Secure Hash Algorithm 256; 'null': No hash algorithm; ", "format": "enum"}, "optional": true}}]}, "auth-method": {"type": "object", "properties": {"preshare-key": {"description": "Authenticate the remote gateway using a pre-shared key", "format": "string", "minLength": 1, "maxLength": 127, "not": "rsa-signature", "type": "string"}, "rsa-signature": {"default": 0, "not": "preshare-key", "type": "number", "description": "Authenticate the remote gateway using an RSA certificate", "format": "flag"}}}}}], "type": "array", "$ref": "/axapi/v3/vpn/ike-gateway/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vpn`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "vpn"
        self.a10_url="/axapi/v3/vpn"
        self.DeviceProxy = ""
        self.ipsec_list = []
        self.fragment_after_encap = ""
        self.revocation_list = []
        self.ike_gateway_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Setting(A10BaseClass):
    
    """Class Description::
    Configure sFlow.

    Class setting supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param source_ip_use_mgmt: {"default": 0, "optional": true, "type": "number", "description": "Use management interface's IP address for source IP of sFlow packets", "format": "flag"}
    :param counter_polling_interval: {"description": "sFlow counter polling interval, default is 20", "format": "number", "default": 20, "optional": true, "maximum": 200, "minimum": 1, "type": "number"}
    :param packet_sampling_rate: {"description": "sFlow packet sampling rate, default is 1000", "format": "number", "default": 1000, "optional": true, "maximum": 1000000, "minimum": 10, "type": "number"}
    :param max_header: {"description": "Configure maximum number of bytes that should be copied from a sampled packet (default: 128) (The maximum number of bytes (Default: 128))", "format": "number", "default": 128, "optional": true, "maximum": 512, "minimum": 14, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/sflow/setting`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "setting"
        self.a10_url="/axapi/v3/sflow/setting"
        self.DeviceProxy = ""
        self.source_ip_use_mgmt = ""
        self.counter_polling_interval = ""
        self.packet_sampling_rate = ""
        self.max_header = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Instance(A10BaseClass):
    
    """Class Description::
    Specify OCSP authentication server name.

    Class instance supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param health_check_string: {"description": "Health monitor name", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/health/monitor"}
    :param responder_cert: {"description": "Specify the trusted OCSP responder's cert filename", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param name: {"description": "Specify OCSP authentication server name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param url: {"description": "Specify the OCSP server's address (Format: http://host[:port]/) (The OCSP server's address(Format: http://host[:port]/))", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param responder_ca: {"description": "Specify the trusted OCSP responder's CA cert filename", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param health_check_disable: {"description": "Disable configured health check configuration", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}
    :param port_health_check_disable: {"description": "Disable configured port health check configuration", "format": "flag", "default": 0, "optional": true, "not": "port-health-check", "type": "number"}
    :param port_health_check: {"description": "Check port's health status", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "port-health-check-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}
    :param health_check: {"description": "Check server's health status", "format": "flag", "default": 0, "optional": true, "not": "health-check-disable", "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/server/ocsp/instance/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "instance"
        self.a10_url="/axapi/v3/aam/authentication/server/ocsp/instance/{name}"
        self.DeviceProxy = ""
        self.health_check_string = ""
        self.responder_cert = ""
        self.name = ""
        self.url = ""
        self.responder_ca = ""
        self.health_check_disable = ""
        self.port_health_check_disable = ""
        self.port_health_check = ""
        self.health_check = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class DeviceGroups(A10BaseClass):
    
    """Class Description::
    configure scaleout device groups.

    Class device-groups supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param device_group_list: {"minItems": 1, "items": {"type": "device-group"}, "uniqueItems": true, "array": [{"required": ["device-group"], "properties": {"device-group": {"description": "scaletout device group", "format": "number", "type": "number", "maximum": 16, "minimum": 1, "optional": false}, "device-id-start": {"optional": true, "type": "number", "format": "number"}, "device-id-end": {"optional": true, "type": "number", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/acos-scaleout/cluster-config/device-groups/device-group/{device-group}"}
    :param enable: {"default": 0, "optional": true, "partition-visibility": "private", "type": "number", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/acos-scaleout/cluster-config/device-groups`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "device-groups"
        self.a10_url="/axapi/v3/acos-scaleout/cluster-config/device-groups"
        self.DeviceProxy = ""
        self.device_group_list = []
        self.enable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param tcp_port_overloading_allocated: {"description": "TCP Port Overloading Allocated", "format": "counter", "type": "number", "oid": "38", "optional": true, "size": "8"}
    :param tcp_session_deleted: {"description": "TCP Session Deleted", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param gre_session_created: {"description": "GRE Session Created", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param icmpv6_resource_freed: {"description": "ICMPV6 Resource Freed", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param icmpv6_session_created: {"description": "ICMPV6 Session Created", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param fixed_nat_periodic_config_logs_sent: {"description": "Fixed NAT Disabled Configs Logged", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "8"}
    :param udp_port_overloading_freed: {"description": "UDP Port Overloading Freed", "format": "counter", "type": "number", "oid": "41", "optional": true, "size": "8"}
    :param tcp_session_created: {"description": "TCP Session Created", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param log_sent: {"description": "Log Packets Sent", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "8"}
    :param udp_port_allocated: {"description": "UDP Port Allocated", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param conn_tcp_dropped: {"description": "TCP Connection Lost", "format": "counter", "type": "number", "oid": "37", "optional": true, "size": "8"}
    :param esp_session_deleted: {"description": "ESP Session Deleted", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param udp_session_created: {"description": "UDP Session Created", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param gre_resource_allocated: {"description": "GRE Resource Allocated", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param udp_port_batch_freed: {"description": "UDP Port Batch Freed", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param fixed_nat_periodic_config_logged: {"description": "Fixed NAT Disabled Config Logs Sent", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "8"}
    :param fixed_nat_disable_config_logged: {"description": "Fixed NAT Periodic Configs Logged", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "8"}
    :param esp_resource_allocated: {"description": "ESP Resource Allocated", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param tcp_port_allocated: {"description": "TCP Port Allocated", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param http_request_logged: {"description": "HTTP Request Logged", "format": "counter", "type": "number", "oid": "42", "optional": true, "size": "8"}
    :param icmp_resource_allocated: {"description": "ICMP Resource Allocated", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param esp_session_created: {"description": "ESP Session Created", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param icmp_resource_freed: {"description": "ICMP Resource Freed", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param icmpv6_session_deleted: {"description": "ICMPV6 Session Deleted", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param tcp_port_overloading_freed: {"description": "TCP Port Overloading Freed", "format": "counter", "type": "number", "oid": "39", "optional": true, "size": "8"}
    :param gre_resource_freed: {"description": "GRE Resource Freed", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param gre_session_deleted: {"description": "GRE Session Deleted", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param udp_port_overloading_allocated: {"description": "UDP Port Overloading Allocated", "format": "counter", "type": "number", "oid": "40", "optional": true, "size": "8"}
    :param fixed_nat_user_ports: {"description": "Fixed NAT Inside User Port Mapping", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "8"}
    :param tcp_port_freed: {"description": "TCP Port Freed", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param icmp_session_deleted: {"description": "ICMP Session Deleted", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param icmp_session_created: {"description": "ICMP Session Created", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param conn_tcp_established: {"description": "TCP Connection Established", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "8"}
    :param fixed_nat_disable_config_logs_sent: {"description": "Fixed NAT Periodic Config Logs Sent", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "8"}
    :param udp_port_batch_allocated: {"description": "UDP Port Batch Allocated", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param udp_port_freed: {"description": "UDP Port Freed", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param esp_resource_freed: {"description": "ESP Resource Freed", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "8"}
    :param tcp_port_batch_freed: {"description": "TCP Port Batch Freed", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param log_dropped: {"description": "Log Packets Dropped", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "8"}
    :param icmpv6_resource_allocated: {"description": "ICMPV6 Resource Allocated", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param udp_session_deleted: {"description": "UDP Session Deleted", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param tcp_port_batch_allocated: {"description": "TCP Port Batch Allocated", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.tcp_port_overloading_allocated = ""
        self.tcp_session_deleted = ""
        self.gre_session_created = ""
        self.icmpv6_resource_freed = ""
        self.icmpv6_session_created = ""
        self.fixed_nat_periodic_config_logs_sent = ""
        self.udp_port_overloading_freed = ""
        self.tcp_session_created = ""
        self.log_sent = ""
        self.udp_port_allocated = ""
        self.conn_tcp_dropped = ""
        self.esp_session_deleted = ""
        self.udp_session_created = ""
        self.gre_resource_allocated = ""
        self.udp_port_batch_freed = ""
        self.fixed_nat_periodic_config_logged = ""
        self.fixed_nat_disable_config_logged = ""
        self.esp_resource_allocated = ""
        self.tcp_port_allocated = ""
        self.http_request_logged = ""
        self.icmp_resource_allocated = ""
        self.esp_session_created = ""
        self.icmp_resource_freed = ""
        self.icmpv6_session_deleted = ""
        self.tcp_port_overloading_freed = ""
        self.gre_resource_freed = ""
        self.gre_session_deleted = ""
        self.udp_port_overloading_allocated = ""
        self.fixed_nat_user_ports = ""
        self.tcp_port_freed = ""
        self.icmp_session_deleted = ""
        self.icmp_session_created = ""
        self.conn_tcp_established = ""
        self.fixed_nat_disable_config_logs_sent = ""
        self.udp_port_batch_allocated = ""
        self.udp_port_freed = ""
        self.esp_resource_freed = ""
        self.tcp_port_batch_freed = ""
        self.log_dropped = ""
        self.icmpv6_resource_allocated = ""
        self.udp_session_deleted = ""
        self.tcp_port_batch_allocated = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Logging(A10BaseClass):
    
    """Class Description::
    Statistics for the object logging.

    Class logging supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/logging/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "logging"
        self.a10_url="/axapi/v3/cgnv6/logging/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IdentityProvider(A10BaseClass):
    
    """Class Description::
    Authentication identity provider.

    Class identity-provider supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "SAML authentication identity provider name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param certificate: {"description": "SAML identity provider certificate file", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param metadata: {"description": "URL of SAML identity provider's metadata file", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/saml/identity-provider/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "identity-provider"
        self.a10_url="/axapi/v3/aam/authentication/saml/identity-provider/{name}"
        self.DeviceProxy = ""
        self.name = ""
        self.certificate = ""
        self.metadata = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class VirtualPort(A10BaseClass):
    
    """Class Description::
    Virtual port template.

    Class virtual-port supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param aflow: {"default": 0, "optional": true, "type": "number", "description": "Use aFlow to eliminate the traffic surge", "format": "flag"}
    :param conn_limit: {"description": "Connection limit", "format": "number", "type": "number", "maximum": 8000000, "minimum": 1, "optional": true}
    :param conn_rate_limit_no_logging: {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}
    :param drop_unknown_conn: {"default": 0, "optional": true, "type": "number", "description": "Drop conection if receives TCP packet without SYN or RST flag and it does not belong to any existing connections", "format": "flag"}
    :param name: {"description": "Virtual port template name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param allow_vip_to_rport_mapping: {"default": 0, "optional": true, "type": "number", "description": "Allow mapping of VIP to real port", "format": "flag"}
    :param conn_limit_reset: {"default": 0, "optional": true, "type": "number", "description": "Send client reset when connection over limit", "format": "flag"}
    :param conn_rate_limit_reset: {"default": 0, "optional": true, "type": "number", "description": "Send client reset when connection rate over limit", "format": "flag"}
    :param rate_interval: {"description": "'100ms': Use 100 ms as sampling interval; 'second': Use 1 second as sampling interval; ", "format": "enum", "default": "second", "type": "string", "enum": ["100ms", "second"], "optional": true}
    :param dscp: {"description": "Differentiated Services Code Point (DSCP to Real Server IP Mapping Value)", "format": "number", "type": "number", "maximum": 63, "minimum": 1, "optional": true}
    :param ignore_tcp_msl: {"default": 0, "optional": true, "type": "number", "description": "reclaim TCP resource immediately without MSL", "format": "flag"}
    :param snat_port_preserve: {"default": 0, "optional": true, "type": "number", "description": "Source NAT Port Preservation", "format": "flag"}
    :param conn_rate_limit: {"description": "Connection rate limit", "format": "number", "type": "number", "maximum": 1048575, "minimum": 1, "optional": true}
    :param reset_l7_on_failover: {"default": 0, "optional": true, "type": "number", "description": "Send reset to L7 client and server connection upon a failover", "format": "flag"}
    :param conn_limit_no_logging: {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}
    :param snat_msl: {"description": "Source NAT MSL (Source NAT MSL value)", "format": "number", "type": "number", "maximum": 1800, "minimum": 1, "optional": true}
    :param allow_syn_otherflags: {"default": 0, "optional": true, "type": "number", "description": "Allow initial SYN packet with other flags", "format": "flag"}
    :param reset_unknown_conn: {"default": 0, "optional": true, "type": "number", "description": "Send reset back if receives TCP packet without SYN or RST flag and it does not belong to any existing connections", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/virtual-port/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "virtual-port"
        self.a10_url="/axapi/v3/slb/template/virtual-port/{name}"
        self.DeviceProxy = ""
        self.aflow = ""
        self.conn_limit = ""
        self.conn_rate_limit_no_logging = ""
        self.drop_unknown_conn = ""
        self.name = ""
        self.allow_vip_to_rport_mapping = ""
        self.conn_limit_reset = ""
        self.conn_rate_limit_reset = ""
        self.rate_interval = ""
        self.dscp = ""
        self.ignore_tcp_msl = ""
        self.snat_port_preserve = ""
        self.conn_rate_limit = ""
        self.reset_l7_on_failover = ""
        self.conn_limit_no_logging = ""
        self.snat_msl = ""
        self.allow_syn_otherflags = ""
        self.reset_unknown_conn = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AreaList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param area_id_addr: {"type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}
    :param tag: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Set the OSPFv3 process tag", "format": "string"}
    :param instance_id: {"description": "Set the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}
    :param area_id_num: {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "area-list"
        self.DeviceProxy = ""
        self.area_id_addr = ""
        self.tag = ""
        self.instance_id = ""
        self.area_id_num = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ospf(A10BaseClass):
    
    """Class Description::
    Open Shortest Path First for IPv6 (OSPFv3).

    Class ospf supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param area_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"area-id-addr": {"type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}, "tag": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Set the OSPFv3 process tag", "format": "string"}, "optional": true, "instance-id": {"description": "Set the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}, "area-id-num": {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/ethernet/{ifnum}/ipv6/router/ospf`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ospf"
        self.a10_url="/axapi/v3/interface/ethernet/{ifnum}/ipv6/router/ospf"
        self.DeviceProxy = ""
        self.area_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Background(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param bgfile: {"description": "Specify background image filename", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "bgcolor", "type": "string"}
    :param bgstyle: {"enum": ["tile", "stretch", "fit"], "type": "string", "description": "'tile': Tile; 'stretch': Stretch; 'fit': Fit; ", "format": "enum"}
    :param bgcolor_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "bgcolor-name", "type": "string"}
    :param bgcolor_name: {"not": "bgcolor-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param bgcolor: {"default": 0, "not": "bgfile", "type": "number", "description": "Specify background color", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "background"
        self.DeviceProxy = ""
        self.bgfile = ""
        self.bgstyle = ""
        self.bgcolor_value = ""
        self.bgcolor_name = ""
        self.bgcolor = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class FailMsgCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param fail_font_custom: {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "fail-face", "type": "string"}
    :param fail_color: {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}
    :param fail_size: {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param fail_msg: {"default": 0, "type": "number", "description": "Configure login failure message in default logon page", "format": "flag"}
    :param fail_text: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify login failure message (Default: Invalid username or password. Please try again.)", "format": "string-rlx"}
    :param fail_color_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "fail-color-name", "type": "string"}
    :param fail_font: {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}
    :param fail_color_name: {"not": "fail-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param fail_face: {"not": "fail-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "fail-msg-cfg"
        self.DeviceProxy = ""
        self.fail_font_custom = ""
        self.fail_color = ""
        self.fail_size = ""
        self.fail_msg = ""
        self.fail_text = ""
        self.fail_color_value = ""
        self.fail_font = ""
        self.fail_color_name = ""
        self.fail_face = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PasswordCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param pass_color_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "pass-color-name", "type": "string"}
    :param pass_color: {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}
    :param pass_color_name: {"not": "pass-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param pass_face: {"not": "pass-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}
    :param pass_font_custom: {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "pass-face", "type": "string"}
    :param pass_size: {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param pass_text: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify password text (Default: Password)", "format": "string-rlx"}
    :param pass_font: {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}
    :param password: {"default": 0, "type": "number", "description": "Configure password text in default logon page", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "password-cfg"
        self.DeviceProxy = ""
        self.pass_color_value = ""
        self.pass_color = ""
        self.pass_color_name = ""
        self.pass_face = ""
        self.pass_font_custom = ""
        self.pass_size = ""
        self.pass_text = ""
        self.pass_font = ""
        self.password = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class UsernameCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param username: {"default": 0, "type": "number", "description": "Configure username text in default logon page", "format": "flag"}
    :param user_font: {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}
    :param user_text: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify username text (Default: User Name)", "format": "string-rlx"}
    :param user_size: {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param user_color_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "user-color-name", "type": "string"}
    :param user_font_custom: {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "user-face", "type": "string"}
    :param user_color: {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}
    :param user_face: {"not": "user-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}
    :param user_color_name: {"not": "user-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "username-cfg"
        self.DeviceProxy = ""
        self.username = ""
        self.user_font = ""
        self.user_text = ""
        self.user_size = ""
        self.user_color_value = ""
        self.user_font_custom = ""
        self.user_color = ""
        self.user_face = ""
        self.user_color_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Logon(A10BaseClass):
    
    """Class Description::
    Logon page configuration.

    Class logon supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param action_url: {"description": "Specify form action URL in default logon page (Default: /logon.fo)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param password_var: {"description": "Specify password variable name in default logon page (Default: pwd)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param username_var: {"description": "Specify username variable name in default logon page (Default: user)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param submit_text: {"description": "Specify submit button text in default logon page (Default: Log In)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/portal/{name}/logon`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "logon"
        self.a10_url="/axapi/v3/aam/authentication/portal/{name}/logon"
        self.DeviceProxy = ""
        self.action_url = ""
        self.password_var = ""
        self.username_var = ""
        self.submit_text = ""
        self.background = {}
        self.fail_msg_cfg = {}
        self.password_cfg = {}
        self.username_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ipv4Addr(A10BaseClass):
    
    """Class Description::
    host DNS name or ipv4 address of remote syslog server.

    Class ipv4addr supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param tcp: {"description": "Use TCP as transport protocol", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param host_ipv4: {"optional": false, "type": "string", "description": "Set syslog host ip address", "format": "host"}
    :param port: {"description": "Set remote syslog port number", "format": "number", "default": 514, "optional": true, "maximum": 32767, "minimum": 1, "type": "number"}
    :param use_mgmt_port: {"description": "Use management port for connections", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/logging/host/ipv4addr/{host_ipv4}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "host_ipv4"]

        self.b_key = "ipv4addr"
        self.a10_url="/axapi/v3/logging/host/ipv4addr/{host_ipv4}"
        self.DeviceProxy = ""
        self.tcp = ""
        self.host_ipv4 = ""
        self.port = ""
        self.use_mgmt_port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class EasyRdt(A10BaseClass):
    
    """Class Description::
    Active RDT options.

    Class easy-rdt supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param range_factor: {"description": "Factor of RDT Range, default is 25 (Range Factor of Smooth RDT)", "format": "number", "default": 25, "optional": true, "maximum": 1000, "minimum": 0, "type": "number"}
    :param smooth_factor: {"description": "Factor of Smooth RDT, default is 10", "format": "number", "default": 10, "optional": true, "maximum": 100, "minimum": 0, "type": "number"}
    :param mask: {"default": "/32", "optional": true, "type": "string", "description": "Client IP subnet mask, default is 32", "format": "ipv4-netmask-brief"}
    :param overlap: {"default": 0, "optional": true, "type": "number", "description": "Enable overlap for geo-location to do longest match", "format": "flag"}
    :param limit: {"description": "Limit of valid RDT, default is 16383 (Limit, unit: millisecond)", "format": "number", "default": 16383, "optional": true, "maximum": 16383, "minimum": 1, "type": "number"}
    :param ignore_count: {"description": "Ignore count if RDT is out of range, default is 5", "format": "number", "default": 5, "optional": true, "maximum": 15, "minimum": 0, "type": "number"}
    :param aging_time: {"description": "Aging Time, Unit: min, default is 10", "format": "number", "default": 10, "optional": true, "maximum": 15360, "minimum": 1, "type": "number"}
    :param bind_geoloc: {"default": 0, "optional": true, "type": "number", "description": "Bind RDT to geo-location", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/site/{site_name}/easy-rdt`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "easy-rdt"
        self.a10_url="/axapi/v3/gslb/site/{site_name}/easy-rdt"
        self.DeviceProxy = ""
        self.range_factor = ""
        self.smooth_factor = ""
        self.mask = ""
        self.overlap = ""
        self.limit = ""
        self.ignore_count = ""
        self.aging_time = ""
        self.bind_geoloc = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


